vfbLib.typing.MaskData
======================

.. currentmodule:: vfbLib.typing

.. autoclass:: MaskData
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MaskData.__init__
      ~MaskData.clear
      ~MaskData.copy
      ~MaskData.fromkeys
      ~MaskData.get
      ~MaskData.items
      ~MaskData.keys
      ~MaskData.pop
      ~MaskData.popitem
      ~MaskData.setdefault
      ~MaskData.update
      ~MaskData.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~MaskData.components
      ~MaskData.guides
      ~MaskData.hints
      ~MaskData.imported
      ~MaskData.kerning
      ~MaskData.metrics
      ~MaskData.name
      ~MaskData.nodes
      ~MaskData.num_masters
      ~MaskData.tth
      ~MaskData.num
      ~MaskData.reserved0
   
   